=== modified file 'NEWS'
--- NEWS	2007-02-02 20:30:28 +0000
+++ NEWS	2007-02-03 13:58:27 +0000
@@ -44,6 +44,11 @@
       other for code reuse without requiring users to perform file-renaming
       gymnastics. (Robert Collins)
 
+    * Allow a start message to be passed to the edit_commit_message function.
+      This will be placed in the message offered to the user for editing above
+      the separator. It allows a template commit message to be used more
+      easily. (James Westby)
+
   BUGFIXES:
 
     * ``bzr annotate`` now uses dotted revnos from the viewpoint of the

=== modified file 'bzrlib/msgeditor.py'
--- bzrlib/msgeditor.py	2006-11-11 19:25:25 +0000
+++ bzrlib/msgeditor.py	2007-02-03 13:58:27 +0000
@@ -80,7 +80,8 @@
     { 'bar' : '-' * 14, 'msg' : 'This line and the following will be ignored' }
 
 
-def edit_commit_message(infotext, ignoreline=DEFAULT_IGNORE_LINE):
+def edit_commit_message(infotext, ignoreline=DEFAULT_IGNORE_LINE,
+                        start_message=None):
     """Let the user edit a commit message in a temp file.
 
     This is run if they don't give a message or
@@ -90,6 +91,13 @@
         Text to be displayed at bottom of message for
         the user's reference; currently similar to
         'bzr status'.
+
+    ignoreline:
+        The separator to use above the infotext.
+
+    start_message:
+        The text to place above the separator, if any. This will not be
+        removed from the message after the user has edited it.
     """
     import tempfile
 
@@ -97,15 +105,25 @@
     try:
         tmp_fileno, msgfilename = tempfile.mkstemp(prefix='bzr_log.', dir=u'.')
         msgfile = os.close(tmp_fileno)
+        havefile = False
+        if start_message is not None and start_message != "":
+            havefile = True
+            msgfile = file(msgfilename, "w")
+            msgfile.write("%s\n" % start_message.encode(
+                                     bzrlib.user_encoding, 'replace'))
         if infotext is not None and infotext != "":
             hasinfo = True
-            msgfile = file(msgfilename, "w")
+            if not havefile:
+              msgfile = file(msgfilename, "w")
+              havefile = True
             msgfile.write("\n\n%s\n\n%s" % (ignoreline,
                 infotext.encode(bzrlib.user_encoding, 'replace')))
-            msgfile.close()
         else:
             hasinfo = False
 
+        if havefile:
+          msgfile.close()
+
         if not _run_editor(msgfilename):
             return None
         

=== modified file 'bzrlib/tests/test_msgeditor.py'
--- bzrlib/tests/test_msgeditor.py	2006-10-11 23:08:27 +0000
+++ bzrlib/tests/test_msgeditor.py	2007-02-03 13:58:27 +0000
@@ -120,6 +120,11 @@
         self.assertEqual('test message from fed\n',
                          bzrlib.msgeditor.edit_commit_message(u'\u1234'))
 
+        mutter('edit_commit_message with starting message')
+        self.assertEqual('test message from fed\nstart message\n',
+                         bzrlib.msgeditor.edit_commit_message('',
+                                              start_message='start message\n'))
+
     def test_deleted_commit_message(self):
         working_tree = self.make_uncommitted_tree()
 

